@@ -1,3 +1,4 @@
+"""Module containing the logic for ``twine register``."""
 # Copyright 2015 Ian Cordasco
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,15 +14,30 @@
 # limitations under the License.
 import argparse
 import os.path
+from typing import List, cast
 
-from twine.package import PackageFile
 from twine import exceptions
+from twine import package as package_file
 from twine import settings
 
 
-def register(register_settings, package):
-    repository_url = register_settings.repository_config['repository']
+def register(register_settings: settings.Settings, package: str) -> None:
+    """Pre-register a package name with a repository before uploading a distribution.
 
+    Pre-registration is not supported on PyPI, so the ``register`` command is only
+    necessary if you are using a different repository that requires it.
+
+    :param register_settings:
+        The configured options relating to repository registration.
+    :param package:
+        The path of the distribution to use for package metadata.
+
+    :raises twine.exceptions.TwineException:
+        The registration failed due to a configuration error.
+    :raises requests.HTTPError:
+        The repository responded with an error.
+    """
+    repository_url = cast(str, register_settings.repository_config["repository"])
     print(f"Registering package to {repository_url}")
     repository = register_settings.create_repository()
 
@@ -31,7 +47,7 @@ def register(register_settings, package):
         )
 
     resp = repository.register(
-        PackageFile.from_filename(package, register_settings.comment)
+        package_file.PackageFile.from_filename(package, register_settings.comment)
     )
     repository.close()
 
@@ -44,7 +60,12 @@ def register(register_settings, package):
     resp.raise_for_status()
 
 
-def main(args):
+def main(args: List[str]) -> None:
+    """Execute the ``register`` command.
+
+    :param args:
+        The command-line arguments.
+    """
     parser = argparse.ArgumentParser(
         prog="twine register",
         description="register operation is not required with PyPI.org",
@@ -56,8 +77,8 @@ def main(args):
         help="File from which we read the package metadata.",
     )
 
-    args = parser.parse_args(args)
-    register_settings = settings.Settings.from_argparse(args)
+    parsed_args = parser.parse_args(args)
+    register_settings = settings.Settings.from_argparse(parsed_args)
 
     # Call the register function with the args from the command line
-    register(register_settings, args.package)
+    register(register_settings, parsed_args.package)
