@@ -18,6 +18,7 @@ import functools
 import logging
 import os
 import os.path
+import unicodedata
 from typing import Any, Callable, DefaultDict, Dict, Optional, Sequence, Union
 from urllib.parse import urlparse
 from urllib.parse import urlunparse
@@ -197,10 +198,12 @@ def check_status_code(response: requests.Response, verbose: bool) -> None:
     try:
         response.raise_for_status()
     except requests.HTTPError as err:
-        if response.text:
-            logger.info("Content received from server:\n{}".format(response.text))
-            if not verbose:
-                logger.warning("NOTE: Try --verbose to see response content.")
+        if not verbose:
+            logger.warning(
+                "Error during upload. "
+                "Retry with the --verbose option for more details."
+            )
+
         raise err
 
 
@@ -210,39 +213,64 @@ def get_userpass_value(
     key: str,
     prompt_strategy: Optional[Callable[[], str]] = None,
 ) -> Optional[str]:
-    """Get the username / password from config.
+    """Get a credential (e.g. a username or password) from the configuration.
 
     Uses the following rules:
 
-    1. If it is specified on the cli (`cli_value`), use that.
-    2. If `config[key]` is specified, use that.
-    3. If `prompt_strategy`, prompt using `prompt_strategy`.
-    4. Otherwise return None
+    1. If ``cli_value`` is specified, use that.
+    2. If ``config[key]`` is specified, use that.
+    3. If ``prompt_strategy`` is specified, use its return value.
+    4. Otherwise return ``None``
 
-    :param cli_value: The value supplied from the command line or `None`.
-    :type cli_value: unicode or `None`
-    :param config: Config dictionary
-    :type config: dict
-    :param key: Key to find the config value.
-    :type key: unicode
-    :prompt_strategy: Argumentless function to return fallback value.
-    :type prompt_strategy: function
-    :returns: The value for the username / password
-    :rtype: unicode
+    :param cli_value:
+        The value supplied from the command line.
+    :param config:
+        A dictionary of repository configuration values.
+    :param key:
+        The credential to look up in ``config``, e.g. ``"username"`` or ``"password"``.
+    :param prompt_strategy:
+        An argumentless function to get the value, e.g. from keyring or by prompting
+        the user.
+
+    :return:
+        The credential value, i.e. the username or password.
     """
     if cli_value is not None:
         logger.info(f"{key} set by command options")
         return cli_value
+
     elif config.get(key) is not None:
         logger.info(f"{key} set from config file")
         return config[key]
+
     elif prompt_strategy:
-        return prompt_strategy()
+        warning = ""
+        value = prompt_strategy()
+
+        if not value:
+            warning = f"Your {key} is empty"
+        elif any(unicodedata.category(c).startswith("C") for c in value):
+            # See https://www.unicode.org/reports/tr44/#General_Category_Values
+            # Most common case is "\x16" when pasting in Windows Command Prompt
+            warning = f"Your {key} contains control characters"
+
+        if warning:
+            logger.warning(f"  {warning}. Did you enter it correctly?")
+            logger.warning(
+                "  See https://twine.readthedocs.io/#entering-credentials "
+                "for more information."
+            )
+
+        return value
+
     else:
         return None
 
 
+#: Get the CA bundle via :func:`get_userpass_value`.
 get_cacert = functools.partial(get_userpass_value, key="ca_cert")
+
+#: Get the client certificate via :func:`get_userpass_value`.
 get_clientcert = functools.partial(get_userpass_value, key="client_cert")
 
 
